namespace java com.meituan.mtrace.thrift.model

struct Endpoint {
    1:required i32 ip;
    2:required i16 port;
    3:required string appKey;
}

struct Annotation {
    1:required string value;
    2:required i64 timestamp;
    3:optional i32 duration;
}

struct KVAnnotation {
    1:required string key;
    2:required string value;
    3:optional i64 timestamp;
    4:optional bool index;
}

enum StatusCode {
    SUCCESS,
    EXCEPTION,
    TIMEOUT,
    DROP,
    HTTP_2XX = 12,
    HTTP_3XX = 13,
    HTTP_4XX = 14,
    HTTP_5XX = 15
}

struct TransmittableHeader {
    1: required i64 traceId;
    2: required string spanId;
    3: bool debug;
    4: map<string, string> oneStepContext;
    5: map<string, string> foreverContext;
}

struct ThriftSpan {
    1: optional i64 traceId;
    2: optional string spanId;
    3: required string spanName;
    4: optional Endpoint local; //废弃，由required变为optional
    5: optional Endpoint remote; //废弃，由required变为optional
    6: required i64 start;
    7: required i32 duration;
    8: optional bool clientSide;
    9: optional list<Annotation> annotations; //不再使用,被14:kvAnnoatations取代
    10:optional string type; //不再使用，被12:infraName取代
    11:optional i32 packageSize;
    12:optional string infraName;
    13:optional string infraVersion; // type version
    14:optional list<KVAnnotation> kvAnnotations;
    15:optional StatusCode status;
    16:optional i32 mask;
    17:optional string traceIdV2; //暂时未使用
    18:optional string ip;  //1.2.x新增，相当于4:local中的ip
    19:optional string appkey; //1.2.x新增，相当于4:local中的appkey
    20:optional string rip; //1.2.x新增，相当于5:remote中的ip
    21:optional string rappkey; //1.2.x新增，相当于5:remote中的appkey
    22:optional i16 port; //1.2.x新增，相当于5:local中的port
    23:optional i16 rport; //1.2.x新增，相当于5:remote中的port，OCTO 使用该字段屏蔽异常节点
}

struct ThriftSpanList {
    1: required list<ThriftSpan> spans;
    2: optional i32 var1;
    3: optional string var2;
    4: optional string appkey; //1.2.x新增
    5: optional string ip; //1.2.x新增
}
