namespace java com.sankuai.sjst.rms.ls.table.model

/**
 * @TypeDoc(
 *     description = "桌台详情"
 * )
 */
struct TableComboTO {
        /**
         * @FieldDoc(
         *     description = "桌台活动id，用于清台、转台等操作",
         *     example = "12"
         * )
         */
        1: optional i32 activityId;
        /**
         * @FieldDoc(
         *     description = "桌台id",
         *     example = "22"
         * )
         */
        2: required i64 tableId;
        /**
         * @FieldDoc(
         *     description = "桌台名称",
         *     example = "桌A/桌A-1/联台1"
         * )
         */
        3: optional string name;
        /**
         * @FieldDoc(
         *     description = "座位数",
         *     example = "10"
         * )
         */
        4: optional i32 seats;
        /**
         * @FieldDoc(
         *     description = "用餐人数",
         *     example = "4"
         * )
         */
        5: optional i32 customerCount;
        /**
         * @FieldDoc(
         *     description = "桌台状态 @com.sankuai.sjst.rms.ls.table.common.TableShowStatus",
         *     example = "2"
         * )
         */
        6: optional i32 showStatus;
        /**
         * @FieldDoc(
         *     description = "创建时间",
         *     example = 1552918434001
         * )
         */
        7: optional i64 createdTime;
        /**
         * @FieldDoc(
         *     description = "待支付金额 单位:分",
         *     example = "5000"
         * )
         */
        8: optional i64 debt;
        /**
        * @FieldDoc(
        *     description = "订单ID",
        *     example = "9m2ds34mkl45"
        * )
        */
        9: optional string orderId;
        /**
        * @FieldDoc(
        *     description = "排序值，越大越靠后。用于刚开始桌台上没有活动的时候的排序",
        *     example = "3"
        * )
        */
        10: optional i32 rank;
        /**
         * @FieldDoc(
         *     description = "虚拟编号",
         *     example = "3091"
         * )
         */
        11: optional i32 virtualNum;
        /**
         * @FieldDoc(
         *     description = "桌台类型，1是正常桌台，2是虚拟桌台，3联台",
         *     example = "2"
         * )
         */
        12: optional i32 type;
        /**
        * @FieldDoc(
        *     description = "联台使用的，作为区分一个联台区的",
        *     example = "2"
        * )
        */
        13: optional i32 parentId;
        /**
        * @FieldDoc(
        *     description = "区分是扫码点餐还是pos下的",
        *     example = "2"
        * )
        */
        14: optional i32 source;
        /**
        * @FieldDoc(
        *     description = "是否是会员",
        *     example = "2"
        * )
        */
        15: optional bool member;
        /**
        * @FieldDoc(
        *     description = "订单版本号",
        *     example = "2"
        * )
        */
        16: optional i32 orderVersion;
        /**
        * @FieldDoc(
        *     description = "是否是反结单， true-反结单，false-否",
        *     example = "true"
        * )
        */
        17: optional bool strike;
        /**
         * @FieldDoc(
         *     description = "桌台助记符",
         *     example = "03"
         * )
         */
        18: optional i32 no;
        /**
         * @FieldDoc(
         *     description = "桌台类型",
         *     example = "1：非堂食；2：堂食"
         * )
         */
        19: optional i32 tableType;
        /**
         * @FieldDoc(
         *     description = "拼音助记符",
         *     example = "DT01"
         * )
         */
        20: optional string pinyin;
        /**
         * @FieldDoc(
         *     description = "菜品价格种类",
         *     example = "2"
         * )
         */
        21: optional i32 goodsPriceCategoryCode;
}

/**
 * @TypeDoc(
 *     description = "区域详情"
 * )
 */
struct AreaTO {
        /**
         * @FieldDoc(
         *     description = "区域id",
         *     example = 1
         * )
         */
        1: required i32 id;
        /**
         * @FieldDoc(
         *     description = "区域名称",
         *     example = "大厅"
         * )
         */
        2: required string name;
        /**
         * @FieldDoc(
         *     description = "区域rank值，越大越靠后",
         *     example = "3"
         * )
         */
        3: required i32 rank
}


/**
 * @TypeDoc(
 *     description = "区域下桌台列表"
 * )
 */
struct AreaTables {
        /**
         * @FieldDoc(
         *     description = "区域信息"
         * )
         */
        1: required AreaTO area;
        /**
         * @FieldDoc(
         *     description = "桌台列表"
         * )
         */
        2: required list<TableComboTO> tableComboTOList
}

/**
 * @TypeDoc(
 *     description = "联台对象请求体"
 * )
 */
struct UnionTableTO {
        /**
         * @FieldDoc(
         *     description = "要联合的tableId集合",
         *     example = "[1,2]"
         * )
         */
        1: required list<i64> tableIdList
}

/**
 * @TypeDoc(
 *     description = "状态TO"
 * )
 */
struct Status{
        /**
             * @FieldDoc(
             *     description = "状态码 非0就是异常",
             *     example = 0
             * )
             */
        1: required i32 code; //状态码
        /**
             * @FieldDoc(
             *     description = "提示信息",
             *     example = "ok"
             * )
             */
        2: optional string msg;
}

/**
 * @TypeDoc(
 *     description = "封装的AreaTables集合列表对象"
 * )
 */
struct AreaTableList {
        /**
         * @FieldDoc(
         *     description = "AreaTables集合列表集合"
         *
         * )
         */
        1: required list<AreaTables> areaTables;
}

/**
 * @TypeDoc(
 *     description = "封装的AreaTO集合对象"
 * )
 */
struct AreaTOList {
        /**
         * @FieldDoc(
         *     description = "AreaTO集合列表"
         *
         * )
         */
        1: required list<AreaTO> AreaTOs;
}
/**
 * @TypeDoc(
 *     description = "封装的联台列表Item"
 * )
 */
struct UnionItem {
        /**
         * @FieldDoc(
         *     description = "联台区负责填充联台区name，比如：联台-1"
         * )
         */
        1: required TableComboTO parentItem;
        /**
        * @FieldDoc(
        *     description = "连联台列表"
        * )
        */
        2: required list<TableComboTO> subItems;
}

/**
 * @TypeDoc(
 *     description = "封装的联台列表集合对象"
 * )
 */
struct UnionTableList {
        /**
        * @FieldDoc(
        *     description = "联台列表，一个item代表一个联台区"
        * )
        */
        1: required list<UnionItem> TableComboTOList;
}



/**
 * @TypeDoc(
 *     description = "封装的TableComboTO集合列表"
 * )
 */
struct TableComboTOList {
        /**
         * @FieldDoc(
         *     description = "TableComboTOs 集合"
         *
         * )
         */
        1: required list<TableComboTO> TableComboTOs;
}

/**
 * @TypeDoc(
 *     description = "转台请求体"
 * )
 */
struct TransferTableReq {
        /**
                 * @FieldDoc(
                 *     description = "门店id",
                 *     example = "11212"
                 * )
                 */
        1: required i32 poiId;
        /**
             * @FieldDoc(
             *     description = "要开台的目标桌台id",
             *     example = "11123"
             * )
             */
        2: required i64 tableId;
        /**
             * @FieldDoc(
             *     description = "开台人数",
             *     example = "3"
             * )
             */
        3: required i32 customerCount;
        /**
            * @FieldDoc(
            *     description = "转台操作人id",
            *     example = "3091"
            * )
            */
        4: required i32 accountId;
        /**
            * @FieldDoc(
            *     description = "目标桌台所在的区域id",
            *     example = "8701"
            * )
            */
        5: optional i32 areaId;
        /**
           * @FieldDoc(
           *     description = "要转台的桌台上的订单id",
           *     example = "8701"
           * )
           */
        6: required string orderId;
        /**
         * @FieldDoc(
         *     description = "转台的原因",
         *     example = "原桌台坐不下"
         * )
         **/
        7: optional string reason;
        /**
         * @FieldDoc(
         *     description = "原始桌台ID",
         *     example = "11123"
         * )
         **/
        8: required i64 originTableId;
        /**
        * @FieldDoc(
        *     description = "是否确认继续转台",
        *     example = "false"
        * )
        **/
        9: optional bool affirm;
}
/**
 * @TypeDoc(
 *     description = "转台请求体"
 * )
 */
struct SimpleTableTO {
        /**
          * @FieldDoc(
          *     description = "目标桌台所在的区域id",
          *     example = "8701"
          * )
          */
        1: required i32 areaId;

        /**
                 * @FieldDoc(
                 *     description = "区域名称",
                 *     example = "11212"
                 * )
                 */
        2: required string areaName;
        /**
             * @FieldDoc(
             *     description = "桌台id",
             *     example = "11123"
             * )
             */
        3: required i64 tableId;
        /**
             * @FieldDoc(
             *     description = "桌台名称",
             *     example = "北京台"
             * )
             */
        4: required string name;
        /**
            * @FieldDoc(
            *     description = "虚拟编号",
            *     example = "3091"
            * )
            */
        5: required i32 virtualNum;

        6: required i32 activityId;
        7: optional string orderId;

}

struct AreaConfigs{
       1: required i32 id;
       2: required i32 poiId;
       3: required i32 rank;
       4: required string name;
}

struct TableConfigs{
        1: required i32 id;
        2: required i32 poiId;
        3: required i32 rank;
        4: required i32 areaId;
        5: required string name;
        6: required i32 no;
        7: required i32 seats;
        8: required i32 status;
        9: optional i64 tableId;
}


struct TableAreaConfigs{
        1: required list<AreaConfigs> areaConfigs;
        2: required list<TableConfigs> tableConfigs;
}

/**
 * @TypeDoc(
 *     description = "服务员绑定桌台请求体"
 * )
 */
struct WaiterBindTableReq{
        /**
         * @FieldDoc(
         *     description = "租户id",
         *     example = {1131}
         * )
         */
        1: required i32 poiId;
        /**
         * @FieldDoc(
         *     description = "服务员id",
         *     example = {2091}
         * )
         */
        2: required i32 waiterId;
        /**
         * @FieldDoc(
         *     description = "入件类型，1是绑定部分桌台，2是绑定全部桌台",
         *     example = {1}
         * )
         */
        3: required i32 type;
        /**
         * @FieldDoc(
         *     description = "桌台id集合",
         *     example = {131}
         * )
         */
        4: required list<i64> tableIdList;
}

struct MergeTableReq {

        1: required i32 fromActivityId;

        2: required string fromOrderId;

        3: required i32 targetActivityId;

        4: required string targetOrderId;
        /**
        * @FieldDoc(
        *     description = "是否确认继续并台",
        *     example = "false"
        * )
        **/
        5: optional bool affirm;

        /**
        * @FieldDoc(
        *     description = "目标桌台的订单类型：0：普通桌台，1：宴会桌台子桌（对应的targetOrderId需要是子桌的orderId）详见枚举/MergeTableTargetOrderBusinessTypeEnum",
        *     example = "1"
        * )
        **/
        6: optional i32 targetOrderBusinessType;

        /**
        * @FieldDoc(
        *     description = "待合并桌台订单是否合并人数致目标桌台：0：默认合并，1：不合并 详见枚举/MergeTableCustomerCountOptionEnum",
        *     example = "1"
        * )
        **/
        7: optional i32 mergeCustomerCountOption;
 }

 struct ChangeGoods {
        /**
         * @FieldDoc(
         *     description = "菜品名称",
         *     example = "孜然羊肉"
         * )
         **/
        1: optional string goodsName;
        /**
         * @FieldDoc(
         *     description = "原桌台菜品价格",
         *     example = 1200
         * )
         **/
        2: optional i64 price;
        /**
         * @FieldDoc(
         *     description = "目标桌台菜品价格",
         *     example = 1500
         * )
         **/
        3: optional i64 newPrice;
 }


struct ChangeDiscountInArea {
        /**
         * @FieldDoc(
         *     description = "促销名称",
         *     example = "整单8折排除梅子酒"
         * )
         **/
        1: optional string discountInfo;
        /**
         * @FieldDoc(
         *     description = "优惠类型",
         *     example = 1200
         * )
         **/
        2: optional i32 type;

 }

 struct TransTableResult {
        /**
         * @FieldDoc(
         *     description = "转台是否成功",
         *     example = "false"
         * )
         **/
        1: optional bool success;
        /**
         * @FieldDoc(
         *     description = "转台需移除菜品列表，菜品名称",
         *     example = {}
         * )
         **/
        2: optional list<string> removeGoodsList;
        /**
         * @FieldDoc(
         *     description = "转台导致发生价格变化的菜品列表",
         *     example = {}
         * )
         **/
        3: optional list<ChangeGoods> changeGoodsList;
        /**
        * @FieldDoc(
        *     description = "桌台信息",
        *     example = {}
        * )
        **/
        4: optional TableComboTO tableComboTO;
        /**
         * @FieldDoc(
         *     description = "转台 / 并台 导致优惠需要移除的优惠",
         *     example = {}
         * )
         **/
        5: optional list<ChangeDiscountInArea> removeDiscountList;

 }

 /**
  * @TypeDoc(
  *     description = "桌台的详细信息"
  * )
  */
 struct TableInfoTO {
         /**
           * @FieldDoc(
           *     description = "桌台id",
           *     example = "8701"
           * )
           */
         1: required i64 tableId;

         /**
                  * @FieldDoc(
                  *     description = "桌台名称",
                  *     example = "大桌子"
                  * )
                  */
         2: required string tableName;

         /**
             * @FieldDoc(
             *     description = "桌台所在的区域id",
             *     example = "3091"
             * )
             */
         3: required i32 areaId;

            /**
             * @FieldDoc(
             *     description = "区域名称",
             *     example = "大厅"
             * )
             */
         4: required string areaName;

         /**
              * @FieldDoc(
              *     description = "桌台类型",
              *     example = "1堂食"
              * )
              */
         5: required i32 tableType;
 }
