namespace java com.sankuai.sjst.rms.ls.table.service

include '../model/Model.thrift'
include '../model/TableComboTO.thrift'
include '../model/TableInfoTOs.thrift'
include '../common/RequestContext.thrift'
include '../model/TableBookTO.thrift'
include '../req/BookTableReq.thrift'
include '../req/CancelBookReq.thrift'
include '../req/UnionTablesReq.thrift'
include '../req/Book2DinnerReq.thrift'
include '../req/QueryTablesBookReq.thrift'
include '../model/TableStatusTO.thrift'
include '../model/OpenTableReq.thrift'


service TableService {

        /**
         * @MethodDoc(
         *     displayName = "根据订单id获取桌台信息",
         *     description = "",
         *     parameters = {
         *         @ParamDoc( name = "poiId", description = "", example = {}),
         *         @ParamDoc( name = "orderId", description = "", example = {})
         *     },
         *     returnValueDescription = "",
         *     extensions = {
         *         @ExtensionDoc(name = "SECURITY_PRIVILEGE", content = "鉴权逻辑为：")
         *     }
         * )
         */
        Model.SimpleTableTO getActivityByOrderId(1: required i32 poiId, 2: required string orderId);

        /**
 * @MethodDoc(
 *     description = "清台",
 *     displayName = "清台",
 *     parameters = {
 *         @ParamDoc(
 *             name = "poiId",
 *             description = "门店id",
 *             example = "1231"
 *         ),
 *         @ParamDoc(
 *             name = "orderIdList",
 *             description = "订单id集合",
 *             example = "{sj3ns0djkn2}"
 *         )
 *     },
 *     exceptions = {
 *         @ExceptionDoc(
 *             name = "e",
 *             description = "TableException"
 *         )
 *     },
 *     returnValueDescription = "不返回"
 * )
 */
        bool clearTable(1: required i32 poiId, 2: required list<string> orderIdList);
        /**
         * @MethodDoc(
         *     description = "转台",
         *     displayName = "转台",
         *     parameters = {
         *         @ParamDoc(
         *             name = "context",
         *             description = "上下文",
         *             example = "12123"
         *         ),
         *
         *         @ParamDoc(
         *             name = "req",
         *             description = "转台请求体",
         *             example = "123"
         *         )
         *     },
         *
         *     returnValueDescription = "返回转台后的桌台对象"
         * )
         */
        TableComboTO.TableComboTO transferTable(1: required RequestContext.Context context, 2: required Model.TransferTableReq req);
        /**
         * @MethodDoc(
         *     description = "合单",
         *     displayName = "合单",
         *     parameters = {
         *         @ParamDoc(
         *             name = "context",
         *             description = "请求上下文",
         *             example = "3421"
         *         ),
         *         @ParamDoc(
         *             name = "fromOrderId",
         *             description = "要被合对订单ID",
         *             example = "sahflk234"
         *         ),
         *         @ParamDoc(
         *             name = "targetOrderId",
         *             description = "目标订单id",
         *             example = "dhakh23sd"
         *         )
         *     },
         *
         *     returnValueDescription = "返回合单后的桌台对象"
         * )
         */
        TableComboTO.TableComboTO mergeTable(1: required RequestContext.Context context, 2: required string fromOrderId, 3: required string targetOrderId);

        /**
         * @MethodDoc(
         *     description = "开台接口",
         *     displayName = "开台接口",
         *     parameters = {
         *         @ParamDoc(
         *             name = "poiId",
         *             description = "门店ID",
         *             example = "1321"
         *         ),
         *
         *         @ParamDoc(
         *             name = "openTableReq",
         *             description = "开台请求体"
         *
         *         ),
         *          @ParamDoc(
         *             name = "openType",
         *             description = "开台请求类型，1是开台，2是拼桌"
         *
         *         )
         *     },
         *     returnValueDescription = "返回开台后的对象"
         * )
         */
        TableComboTO.TableComboTO openTable(1: required i32 poiId, 2: required OpenTableReq.OpenTableReq openTableReq, 3:required i32 openType);

        /**
         * @MethodDoc(
         *     description = "撤台",
         *     displayName = "撤台",
         *     parameters = {
         *         @ParamDoc(
         *             name = "context",
         *             description = "请求上下文",
         *             example = "1231"
         *         ),
         *         @ParamDoc(
         *             name = "activityId",
         *             description = "活动id",
         *             example = "8790"
         *         )
         *     },
         *     returnValueDescription = "不返回，"
         * )
         */
        bool cancelTable(1: required RequestContext.Context context, 2: required i32 activityId);

        list<Model.TableInfoTO> getAllTables(1: required i32 poiId);


        Model.AreaTOList getAreaList(1: required i32 poiId);

        Model.AreaTableList getAreaTables(1: required i32 poiId, 2: required list<i32> areaIds);
        Model.AreaTableList getAreaTablesFromDeviceConfig(1: required i32 poiId, 2: required list<i32> areaIds);

        Model.AreaTableList getNoStateAreaTables(1: required i32 poiId, 2: required list<i32> areaIds);

        void updateCustomerCount(1: required i32 poiId, 2: required string orderId, 3: required i32 customerCount);

        void bindWaiterTables(1: required i32 poiId, 2: required i32 waiterId, 3: required i32 bindType, 4: required list<i64> tableIdList);

        Model.AreaTableList getWaiterTables(1: required i32 poiId, 2: required i32 waiterId);

        /**
         * @MethodDoc(
         *     displayName = "根据桌台id获取桌台信息集合",
         *     description = "",
         *     parameters = {
         *         @ParamDoc( name = "poiId", description = "门店ID", example = {}),
         *         @ParamDoc( name = "tableIdList", description = "桌台id集合", example = {})
         *     },
         *     returnValueDescription = "返回桌台集合"
         * )
         */
        Model.TableComboTOList getActivityByTableId(1: required i32 poiId, 2: required list<i64> tableIdList);

        /**
         * @MethodDoc(
         *     displayName = "根据桌台id集合获取桌台状态信息",
         *     description = "根据桌台id集合获取桌台状态信息，详见TableConstants.RmsTableStatusEnum",
         *     parameters = {
         *         @ParamDoc( name = "poiId", description = "门店ID"),
         *         @ParamDoc( name = "ids", description = "桌台id集合")
         *     },
         *     returnValueDescription = "返回桌台集合"
         * )
         */
        list<TableStatusTO.TableStatusTO> getTableStatusByIds(1: required i32 poiId, 2: required list<i64>
        ids)

        /**
         * @MethodDoc(
         *     displayName = "根据桌台id集合获取桌台信息",
         *     description = "根据桌台id集合获取桌台信息,包含桌台活动",
         *     parameters = {
         *         @ParamDoc( name = "poiId", description = "门店ID"),
         *         @ParamDoc( name = "ids", description = "桌台id集合")
         *     },
         *     returnValueDescription = "桌台信息"
         * )
         */
        Model.TableComboTOList getTableWithActivityByIds(1: required i32 poiId, 2: required list<i64>
        ids)

        /**
         * @MethodDoc(
         *     displayName = "获取当前活跃的桌台列表",
         *     description = "获取当前活跃（在使用中）的桌台列表",
         *     parameters = {
         *         @ParamDoc( name = "poiId", description = "门店ID", example = {})
         *     },
         *     returnValueDescription = "桌台列表"
         * )
         **/
        Model.TableComboTOList listBusyTables(1: required i32 poiId);

        i64 getTableIdByNo(1: required i32 poiId, 2: required i32 tableNo);
        /**
         * @MethodDoc(
         *     displayName = "根据桌台ID获取桌台",
         *     description = "根据桌台ID获取桌台",
         *     parameters = {
         *         @ParamDoc( name = "poiId", description = "门店ID", example = {})
         *         @ParamDoc( name = "tableNo", description = "桌台助记码", example = {})
         *     },
         *     returnValueDescription = "TableConfigs"
         * )
         **/
        Model.TableConfigs getTableByNo(1: required i32 poiId, 2: required i32 tableNo);

        list<TableComboTO.TableComboTO> getBusyActivity(1: required i32 poiId, 2: required i64 tableId);

        Model.AreaTableList getTableConfigs4Waiter(1: required i32 poiId);

        Model.AreaTableList getFreeTables(1: required i32 poiId);

        Model.UnionTableList getUnionTables(1: required i32 poiId, 2: required i32 unionType);


        /**
         * @MethodDoc(
         *     displayName = "联台接口",
         *     description = "把桌台进行联台操作",
         *     parameters = {
         *         @ParamDoc( name = "openTableReqList", description = "", example = {})
         *     },
         *     extensions = {
         *         @ExtensionDoc(name = "SECURITY_PRIVILEGE", content = "鉴权逻辑为：")
         *     }
         * )
         */
        Model.UnionItem unionTables(1: required UnionTablesReq.UnionTablesReq unionReq);

        void updateUnion(1: required UnionTablesReq.UnionTablesReq unionReq);

        void cancelUnion(1: required i32 parentId, 2: required list<OpenTableReq.OpenTableReq> openTableReqList);

        TableComboTO.TableComboTO getTableComboByOrderId(1: required i32 poiId, 2: required string orderId);

        void clearUnion(1: required i32 parentId);

        void batchClearUnionByParentOrderId(1:list<string> parentOrderIdList);

        Model.TableComboTOList getTableByTableIds(1: required i32 poiId, 2: required list<i64> tableIdList);

        map<i64,i32>  getAreasByTableIds(1: required i32 poiId, 2: required list<i64> tableIdList);

        Model.UnionItem getUnionItemByParentOrderId (1:required string parentOrderId)

        bool validTableId(1: required i32 poiId, 2: required i64 tableId);

        bool strikeOpenTable(1: required OpenTableReq.OpenTableReq openTableReq);

        bool strikeUnionTable(1: required UnionTablesReq.UnionTablesReq unionReq);

        bool cancelBook(1: required i32 poiId, 2: required CancelBookReq.CancelBookReq cancelReq);

        bool openBookActivity(1:required BookTableReq.BookTableReq bookReq);

        /**
         * @MethodDoc(
         *     displayName = "根据桌台id获取桌台信息",
         *     description = "",
         *     parameters = {
         *         @ParamDoc( name = "poiId", description = "", example = {}),
         *         @ParamDoc( name = "tableId", description = "", example = {})
         *     },
         *     returnValueDescription = "",
         *     extensions = {
         *         @ExtensionDoc(name = "SECURITY_PRIVILEGE", content = "鉴权逻辑为：")
         *     }
         * )
         */
        Model.TableInfoTO getTableInfoById(1: required i32 poiId, 2: required i64 tableId);

       /**
         * @MethodDoc(
         *     displayName = "根据桌台id获取桌台信息",
         *     description = "",
         *     parameters = {
         *         @ParamDoc( name = "poiId", description = "", example = {}),
         *         @ParamDoc( name = "tableId", description = "", example = {})
         *     },
         *     returnValueDescription = "",
         *     extensions = {
         *         @ExtensionDoc(name = "SECURITY_PRIVILEGE", content = "鉴权逻辑为：")
         *     }
         * )
         */
        list<Model.TableInfoTO> getTablesInfoByIds(1: required i32 poiId, 2: required list<i64> tableIds);

       /**
         * @MethodDoc(
         *     displayName = "预定转到堂食",
         *     description = "预定转到堂食",
         *     parameters = {
         *         @ParamDoc( name = "openTableReqList", description = "", example = {})
         *     },
         *     extensions = {
         *         @ExtensionDoc(name = "SECURITY_PRIVILEGE", content = "鉴权逻辑为：")
         *     }
         * )
         */
        Model.UnionItem book2Dinner(1: required Book2DinnerReq.Book2DinnerReq book2DinnerReq);

        bool handleBookActivities4pull(1:required list<BookTableReq.BookTableReq> bookReqs);

        list<TableBookTO.TableBookTO> queryTablesBook(1: required QueryTablesBookReq.QueryTablesBookReq queryReq);

        Model.AreaTO queryAreaByName(1: required i32 poiId, 2: required string areaName);

        list<Model.TableInfoTO> queryTablesByName(1: required i32 poiId, 2: required string tableName);

        list<TableComboTO.TableComboTO> getActivitiesByOrderIds(1: required i32 poiId, 2: required list<string> orderIds);

        list<Model.SimpleTableTO> getActivityByOrderIds(1: required i32 poiId, 2: required list<string> orderIds);

         Model.AreaTOList getAreasByIds(1: required i32 poiId, 2: required list<i32> areaIds);

        void refreshConfigFromCloud();

        bool updateBookActivity(1:required BookTableReq.BookTableReq bookReq);

        /**
         * @MethodDoc(
         *     displayName = "单个桌台的正餐预定转堂食",
         *     description = "单个桌台的正餐预定转堂食",
         *     parameters = {
         *         @ParamDoc( name = "openTableReqList", description = "", example = {})
         *     },
         *     extensions = {
         *         @ExtensionDoc(name = "SECURITY_PRIVILEGE", content = "鉴权逻辑为：")
         *     }
         * )
         */
        Model.TableComboTO singleDinnerBook2Dinner(1: required OpenTableReq.OpenTableReq openTableReq, 2: required string bookOrderId);



        Model.TableComboTOList getActiesByOrderIdsIgnoreStatus(1: required RequestContext.Context context, 2: required list<string> orderIds);
        }

