
namespace java com.sankuai.sjst.rms.ls.rota.to.detail


/**
 * @TypeDoc(
 *     description = "现金实收明细列表请求"
 * )
 */
struct RotaPaymentDetailReq {
        /**
        * @FieldDoc(
        *     description = "支付方式",
        *     example = ""
        * )
        */
        1: optional i32 payMethodCode;
        /**
        * @FieldDoc(
        *     description = "开始时间",
        *     example = ""
        * )
        */
        2: optional i64 startTime;
        /**
        * @FieldDoc(
        *     description = "结束时间",
        *     example = ""
        * )
        */
        3: optional i64 endTime;
        /**
        * @FieldDoc(
        *     description = "班次id",
        *     example = ""
        * )
        */
        4: optional string rotaId;
        /**
        * @FieldDoc(
        *     description = "支付名称:团购券场景使用",
        *     example = ""
        * )
        */
        5: optional string payTypeName;
}

/**
 * @TypeDoc(
 *     description = "数据明细列表详情"
 * )
 */
struct RotaPaymentTo {
        /**
        * @FieldDoc(
        *     description = "收支类型code:1订单 2会员充退 3挂账还款",
        *     example = ""
        * )
        */
        1: optional i32 paymentCode;
        /**
        * @FieldDoc(
        *     description = "收支类型名称",
        *     example = ""
        * )
        */
        2: optional string paymentName;
        /**
        * @FieldDoc(
        *     description = "支付时间",
        *     example = ""
        * )
        */
        3: optional i64 paymentTime;
        /**
        * @FieldDoc(
        *     description = "支付金额",
        *     example = "30000"
        * )
        */
        4: optional i64 paymentMoney;
        /**
        * @FieldDoc(
        *     description = "张数（团购券详情字段）",
        *     example = "3"
        * )
        */
        5: optional i32 couponNum;
        /**
        * @FieldDoc(
        *     description = "businessType code（冗余）",
        *     example = "3"
        * )
        */
        6: optional i32 businessType;
        /**
        * @FieldDoc(
        *     description = "businessType name（冗余）",
        *     example = ""
        * )
        */
        7: optional string businessName;
        /**
        * @FieldDoc(
        *     description = "日期",
        *     example = "2019-4-8"
        * )
        */
        8: optional string date;
}

/**
 * @TypeDoc(
 *     description = "各业务交班数据详情"
 * )
 */
struct RotaBizPaymentTo {
        /**
        * @FieldDoc(
        *     description = "业务code",
        *     example = ""
        * )
        */
        1: optional i32 bizCode;
        /**
        * @FieldDoc(
        *     description = "业务名称",
        *     example = "会员冲退"
        * )
        */
        2: optional string bizName;
        /**
        * @FieldDoc(
        *     description = "团购券名称",
        *     example = "80抵100"
        * )
        */
        3: optional string groupCouponName;
        /**
        * @FieldDoc(
        *     description = "收支明细",
        *     example = {}
        * )
        */
        4: optional list<RotaPaymentTo> paymentToList;
        /**
        * @FieldDoc(
        *     description = "小计",
        *     example = "179000"
        * )
        */
        5: optional i64 totalMoney;

}

/**
 * @TypeDoc(
 *     description = "各业务交班数据详情每日汇总"
 * )
 */
struct RotaBizPaymentDailyTo {
        /**
        * @FieldDoc(
        *     description = "统计日期",
        *     example = ""
        * )
        */
        1: optional i64 date;
        /**
        * @FieldDoc(
        *     description = "现金实收笔数",
        *     example = "8"
        * )
        */
        2: optional i32 totalCount;
        /**
        * @FieldDoc(
        *     description = "现金实收金额",
        *     example = "30000"
        * )
        */
        3: optional i64 totalMoney;
        /**
        * @FieldDoc(
        *     description = "验券笔数",
        *     example = "8"
        * )
        */
        4: optional i32 groupCouponPayCount;
        /**
        * @FieldDoc(
        *     description = "撤销笔数",
        *     example = "8"
        * )
        */
        5: optional i32 groupCouponCancelCount;
        /**
        * @FieldDoc(
        *     description = "挂账笔数",
        *     example = "8"
        * )
        */
        6: optional i32 onAccountCount;
        /**
        * @FieldDoc(
        *     description = "挂账金额",
        *     example = "8"
        * )
        */
        7: optional i64 onaccountMoney;
        /**
        * @FieldDoc(
        *     description = "各业务收支明细",
        *     example = {}
        * )
        */
        8: optional list<RotaBizPaymentTo> bizPaymentToList;
}

/**
 * @TypeDoc(
 *     description = "各业务交班数据详情每日汇总列表resp"
 * )
 */
struct RotaBizPaymentDailyToResp {
        /**
        * @FieldDoc(
        *     description = "明细列表",
        *     example = {}
        * )
        */
        1: optional list<RotaBizPaymentDailyTo> paymentList;
}

/**
 * @TypeDoc(
 *     description = "交班反结详情"
 * )
 */
struct RotaStrikeDetailTo {
        /**
        * @FieldDoc(
        *     description = "订单号",
        *     example = {}
        * )
        */
        1: optional string orderId;
        /**
        * @FieldDoc(
        *     description = "版本号",
        *     example = {}
        * )
        */
        2: optional i32 orderVersion;
        /**
        * @FieldDoc(
        *     description = "结账人id",
        *     example = {}
        * )
        */
        3: optional i32 operatorId;
        /**
        * @FieldDoc(
        *     description = "结账人name",
        *     example = {}
        * )
        */
        4: optional string operatorName;
        /**
        * @FieldDoc(
        *     description = "结账时间",
        *     example = ""
        * )
        */
        5: optional i64 checkoutTime;
        /**
        * @FieldDoc(
        *     description = "实收金额",
        *     example = "50000"
        * )
        */
        6: optional i64 payMoney;
        /**
        * @FieldDoc(
        *     description = "反结账人id",
        *     example = ""
        * )
        */
        7: optional i32 strikeOperatorId;
        /**
        * @FieldDoc(
        *     description = "反结账人nme",
        *     example = ""
        * )
        */
        8: optional string strikeOperatorName;
        /**
        * @FieldDoc(
        *     description = "反结时间",
        *     example = ""
        * )
        */
        9: optional i64 strikeTime;
        /**
        * @FieldDoc(
        *     description = "反结实收金额",
        *     example = "28000"
        * )
        */
        10: optional i64 strikeMoney;
        /**
        * @FieldDoc(
        *     description = "差额",
        *     example = "20000"
        * )
        */
        11: optional i64 diffMoney;
        /**
        * @FieldDoc(
        *     description = "备注历史",
        *     example = ""
        * )
        */
        12: optional string remarkHistory;
        /**
        * @FieldDoc(
        *     description = "当前备注",
        *     example = ""
        * )
        */
        13: optional string remark;
        /**
        * @FieldDoc(
        *     description = "订单号",
        *     example = {}
        * )
        */
        14: optional string orderNo;
        /**
        * @FieldDoc(
        *     description = "是否被更新",
        *     example = {}
        * )
        */
        15: optional bool modified;
        /**
        * @FieldDoc(
        *     description = "交班备注是否被删除",
        *     example = {}
        * )
        */
        16: optional bool deleteNewRemark;
        /**
        * @FieldDoc(
        *     description = "是否是退单",
        *     example = {}
        * )
        */
        17: optional bool chargeBackFlag;
}

/**
 * @TypeDoc(
 *     description = "交班反结详情列表"
 * )
 */
struct RotaStrikeDetailToResp {
        /**
        * @FieldDoc(
        *     description = "交班反结详情列表",
        *     example = ""
        * )
        */
        1: optional list<RotaStrikeDetailTo> strikeDetailList;
}

/**
 * @TypeDoc(
 *     description = "备用金异常"
 * )
 */
struct RotaImprestMoneyInfoTo {
        /**
        * @FieldDoc(
        *     description = "上次交班人id",
        *     example = {}
        * )
        */
        1: optional i32 lastOperatorId;
        /**
        * @FieldDoc(
        *     description = "上次交班人name",
        *     example = {}
        * )
        */
        2: optional string lastOperatorName;
        /**
        * @FieldDoc(
        *     description = "上次交班时间",
        *     example = ""
        * )
        */
        3: optional i64 checkoutTime;
        /**
        * @FieldDoc(
        *     description = "预留备用金",
        *     example = "50000"
        * )
        */
        4: optional i64 preImprestMoney;
        /**
        * @FieldDoc(
        *     description = "本次交班人",
        *     example = "50000"
        * )
        */
        5: optional i32 operatorId;
        /**
        * @FieldDoc(
        *     description = "本次交班人",
        *     example = "50000"
        * )
        */
        6: optional string operatorName;
        /**
        * @FieldDoc(
        *     description = "本班次实际备用金",
        *     example = "28000"
        * )
        */
        7: optional i64 realImprestMoney;
        /**
        * @FieldDoc(
        *     description = "本班次实际备用金历史，逗号分隔",
        *     example = "28000"
        * )
        */
        8: optional i64 realImprestMoneyHistory;
        /**
        * @FieldDoc(
        *     description = "差额",
        *     example = "20000"
        * )
        */
        9: optional i64 diffMoney;
        /**
        * @FieldDoc(
        *     description = "备注历史",
        *     example = ""
        * )
        */
        10: optional string remarkHistory;
        /**
        * @FieldDoc(
        *     description = "当前备注",
        *     example = ""
        * )
        */
        11: optional string remark;
        /**
        * @FieldDoc(
        *     description = "班次id",
        *     example = ""
        * )
        */
        12: optional string rotaId;
}

/**
 * @TypeDoc(
 *     description = "反结详情明细保存请求"
 * )
 */
struct RotaStrikeDetailReq {
        /**
        * @FieldDoc(
        *     description = "反结订单详情列表（查询反结时不需要传）",
        *     example = {}
        * )
        */
        1: optional list<RotaStrikeDetailTo> strikeDetailList;
        /**
        * @FieldDoc(
        *     description = "反结类型：1反结本班次 2反结跨班次",
        *     example = {}
        * )
        */
        2: optional i32 strikeType;
        /**
        * @FieldDoc(
        *     description = "班次id",
        *     example = ""
        * )
        */
        3: optional string rotaId;
}

/**
 * @TypeDoc(
 *     description = "交班里的订单明细"
 * )
 */
struct RotaOrderDetailTO {
        /**
        * @FieldDoc(
        *     description = "订单Id",
        *     example = {}
        * )
        */
        1: optional string orderId;
        /**
        * @FieldDoc(
        *     description = "订单编号",
        *     example = {}
        * )
        */
        2: optional string orderNo;
        /**
        * @FieldDoc(
        *     description = "下单来源(首次下单)：1-pos, 2-服务员APP,3 用户自助点餐,21-美团外卖,22-eleme外卖,23-预点餐,24-排队预点餐,25-点菜宝",
        *     example = {}
        * )
        */
        3: optional string source;
        /**
        * @FieldDoc(
        *     description = "结账时间",
        *     example = ""
        * )
        */
        4: optional i64 checkoutTime;
        /**
        * @FieldDoc(
        *     description = "结账人",
        *     example = ""
        * )
        */
        5: optional string checkoutCashier;
}

/**
 * @TypeDoc(
 *     description = "交班返回的订单明细，方便支持交班的定制化订单明细查询需求"
 * )
 */
struct RotaOrderDetailListTO {
        /**
        * @FieldDoc(
        *     description = "交班返回的订单明细列表",
        *     example = {}
        * )
        */
        1: optional list<RotaOrderDetailTO> orderDetails;
        /**
        * @FieldDoc(
        *     description = "总数量",
        *     example = ""
        * )
        */
        2: optional i32 count;
}